summaryrefslogtreecommitdiff
path: root/navit/gui
diff options
context:
space:
mode:
authorjkoan <jkoan@users.noreply.github.com>2017-08-25 19:07:46 +0200
committerPierre GRANDIN <pgrandin@users.noreply.github.com>2017-08-25 10:07:46 -0700
commitf5abdd317e10d56226300d001469595658a605e4 (patch)
tree5f2722cb7929d406201730ae967f3f3cf69df8f8 /navit/gui
parent0d5ef51e8cd6dd6e03832e995cdae2a8c02c4da6 (diff)
downloadnavit-f5abdd317e10d56226300d001469595658a605e4.tar.gz
Moved xpm to icons (#307)
Diffstat (limited to 'navit/gui')
-rw-r--r--navit/gui/qml/gui_qml.cpp2
-rw-r--r--navit/gui/qt5_qml/backend.cpp8
2 files changed, 5 insertions, 5 deletions
diff --git a/navit/gui/qml/gui_qml.cpp b/navit/gui/qml/gui_qml.cpp
index 7a1016473..3efc719dd 100644
--- a/navit/gui/qml/gui_qml.cpp
+++ b/navit/gui/qml/gui_qml.cpp
@@ -460,7 +460,7 @@ static struct gui_priv * gui_qml_new(struct navit *nav, struct gui_methods *meth
this_->skin=g_strdup("navit");
}
if ( this_->icon_src==NULL ) {
- this_->icon_src=g_strjoin(NULL,getenv("NAVIT_SHAREDIR"),"/xpm/",NULL);
+ this_->icon_src=g_strjoin(NULL,getenv("NAVIT_SHAREDIR"),"/icons/",NULL);
}
if ((attr=attr_search(attrs, NULL, attr_callback_list))) {
diff --git a/navit/gui/qt5_qml/backend.cpp b/navit/gui/qt5_qml/backend.cpp
index 14cdd4ddf..ac1eb21a5 100644
--- a/navit/gui/qt5_qml/backend.cpp
+++ b/navit/gui/qt5_qml/backend.cpp
@@ -258,12 +258,12 @@ void Backend::setActivePoi(int index) {
}
/**
* @brief returns the icon (xpm) absolute path
* @param none
* @returns the icon (xpm) absolute path as a QString
*/
QString Backend::get_icon_path(){
- return QString(g_strjoin(NULL,"file://",getenv("NAVIT_SHAREDIR"),"/xpm/",NULL));
+ return QString(g_strjoin(NULL,"file://",getenv("NAVIT_SHAREDIR"),"/icons/",NULL));
}
/**
@@ -316,7 +316,7 @@ QString Backend::get_country_icon(char * country_iso_code){
// if ( country_iso_code == "" ) {
// country_iso_code = _country_iso2;
// }
- return QString(g_strjoin(NULL,"file://",getenv("NAVIT_SHAREDIR"),"/xpm/",country_iso_code,".svg",NULL));
+ return QString(g_strjoin(NULL,"file://",getenv("NAVIT_SHAREDIR"),"/icons/",country_iso_code,".svg",NULL));
}
@@ -258,12 +258,12 @@ void Backend::setActivePoi(int index) {
}
/**
- * @brief returns the icon (xpm) absolute path
+ * @brief returns the icon (icons) absolute path
* @param none
@@ -258,12 +258,12 @@ void Backend::setActivePoi(int index) {
* @param none
- * @returns the icon (xpm) absolute path as a QString
+ * @returns the icon (icons) absolute path as a QString
*/
QString Backend::get_icon_path(){